@@ -410,7 +410,14 @@ class MainWindow(QMainWindow):
                 if dialog.exec_():
                     row = dialog.view.selectionModel().selectedRows()[0].row()
                     stream_id = dialog.model.data(dialog.model.index(row, 0))
-                    self.model.load(fname, stream_id=stream_id)
+                    srate = "effective" if dialog.effective_srate else "nominal"
+                    prefix_markers = dialog.prefix_markers
+                    kwargs = {}
+                    if srate == "nominal":
+                        kwargs["srate"] = srate
+                    if prefix_markers:
+                        kwargs["prefix_markers"] = prefix_markers
+                    self.model.load(fname, stream_id=stream_id, **kwargs)
             else:  # all other file formats
                 try:
                     self.model.load(fname)
@@ -471,11 +478,11 @@ class MainWindow(QMainWindow):
         dialog = PickChannelsDialog(self, channels, selected=channels)
         if dialog.exec_():
             picks = [item.data(0) for item in dialog.channels.selectedItems()]
-            drops = set(channels) - set(picks)
+            drops = list(set(channels) - set(picks))
             if drops:
                 self.auto_duplicate()
                 self.model.drop_channels(drops)
-                self.model.history.append(f"raw.drop({drops})")
+                self.model.history.append(f"data.drop_channels({drops})")
 
     def channel_properties(self):
         """Show channel properties dialog."""
